@@ -3,10 +3,9 @@
 #  Licensed under the BSD 3-Clause License. See LICENSE.txt in the project root for license information.
 # ------------------------------------------------------------------------------------------------------
 
-from typing import Tuple
-
 import numpy as np
 
+
 class Coordinate:
     def __init__(self, **kwargs) -> None:
         """
@@ -28,30 +27,30 @@ class Coordinate:
         self._position = self._random.uniform(self.__lower_boundary, self.__upper_boundary, 2)
 
     @property
-    def position(self) -> Tuple[float, float]:
+    def position(self) -> np.ndarray:
         """
         Get the coordinate's position
 
         Returns:
-            Tuple[float, float]: the Position
+            numpy.ndarray: the Position
         """
         return self._position
 
     # Internal Getter
     @property
-    def _position(self) -> Tuple[float, float]:
+    def _position(self) -> np.ndarray:
         return self.__position
 
     # Internal Setter for automatic position clipping and value update
     @_position.setter
-    def _position(self, new_pos: Tuple[float, float]) -> None:
+    def _position(self, new_pos: np.ndarray) -> None:
         """
         Set the coordinate's new position.
         Also updates checks whether the position is within the set boundaries
         and updates the coordinate's value.
 
         Args:
-            value (Tuple[float, float]): The new coordinate position
+            new_pos (numpy.ndarray): The new coordinate position
         """
         self.__position = np.clip(new_pos, a_min=self.__lower_boundary, a_max=self.__upper_boundary)
         self.__value = self._function(self.__position)
@@ -60,15 +59,20 @@ class Coordinate:
     def value(self) -> float:
         return self.__value
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         return self.__value == other.value
-    def __ne__(self, other):
+
+    def __ne__(self, other) -> bool:
         return self.__value != other.value
-    def __lt__(self, other):
+
+    def __lt__(self, other) -> bool:
         return self.__value < other.value
-    def __le__(self, other):
+
+    def __le__(self, other) -> bool:
         return self.__value <= other.value
-    def __gt__(self, other):
+
+    def __gt__(self, other) -> bool:
         return self.__value > other.value
-    def __ge__(self, other):
+
+    def __ge__(self, other) -> bool:
         return self.__value >= other.value
